pub enum SyncJob {
Push {
link_id: String,
},
Pull {
link_id: String,
},
}Expand description
A job dispatched to a daemon worker.
Variants
Push
Push local changes for the given link to the remote.
Pull
Pull remote changes for the given link to the local directory.