Skip to main contentModule link
Source - LinkId
- A stable, deterministic identifier for a link derived from (repo, name).
- LinkInfo
- All persistent metadata about a single link.
- LinkMode
- How the link syncs changes between the local directory and the repo.
- LinkState
- Runtime state of a link (not persisted, tracked in-memory / SQLite).