Module conflict

Module conflict 

Structs

Conflict
A conflict between base, local, and remote versions of a file.
KeepLocalResolver
Always keeps the local version when a conflict is detected.

Enums

FileAction
An action to take for a given file after three-point comparison.
Resolution
How a conflict was resolved.

Traits

ConflictResolver
Trait for resolving conflicts programmatically.

Functions

detect_conflicts
Three-point merge: compare base, local, and remote manifests and return the list of actions that need to be taken.

Type Aliases

ManifestMap
A map from file path to its MD5/blake3/etc. hash (16 bytes).