pub struct LinksRegistry { /* private fields */ }Expand description
In-memory registry of all configured links, backed by links.toml.
Implementations
Sourceimpl LinksRegistry
impl LinksRegistry
pub fn new() -> Self
Sourcepub fn load(path: &Path) -> Result<Self>
pub fn load(path: &Path) -> Result<Self>
Load from a TOML file. Returns an empty registry if the file does not exist.
Sourcepub fn add(&mut self, info: LinkInfo) -> Result<()>
pub fn add(&mut self, info: LinkInfo) -> Result<()>
Add a new link. Returns an error if:
- A link with the same id already exists.
- Another link already points at the same
local_dir(one-dir one-link).
Sourcepub fn remove(&mut self, id: &LinkId) -> Result<()>
pub fn remove(&mut self, id: &LinkId) -> Result<()>
Remove a link by its id. Returns an error if not found.
Sourcepub fn get_by_name(&self, name: &str) -> Option<&LinkInfo>
pub fn get_by_name(&self, name: &str) -> Option<&LinkInfo>
Look up a link by its human-readable name.
Sourcepub fn get_by_dir(&self, dir: &Path) -> Option<&LinkInfo>
pub fn get_by_dir(&self, dir: &Path) -> Option<&LinkInfo>
Look up a link by its local_dir.