Module server

Module server 

Structs

IpcClient
IPC client that connects to a daemon over a Unix domain socket.
IpcRequest
A request sent from an IPC client to the daemon.
IpcResponse
A response sent from the daemon back to the IPC client.
IpcServer
Handle to the IPC server. Drop or call stop() to shut it down.

Type Aliases

CommandSender
Type alias for the channel that sends IPC commands to the daemon command loop.