Module link

Module link 

Structs

LinkId
A stable, deterministic identifier for a link derived from (repo, name).
LinkInfo
All persistent metadata about a single link.

Enums

LinkMode
How the link syncs changes between the local directory and the repo.
LinkState
Runtime state of a link (not persisted, tracked in-memory / SQLite).